@@ -1,16 +1,16 @@
 package Crypt::Random::Source::Base::File;
-BEGIN {
-  $Crypt::Random::Source::Base::File::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: File (or device) random data sources
-$Crypt::Random::Source::Base::File::VERSION = '0.08';
-use Any::Moose;
+
+our $VERSION = '0.12';
+
+use Moo;
 
 use Carp qw(croak);
 
 extends qw(Crypt::Random::Source::Base::Handle);
 
 use IO::File;
+use namespace::clean;
 
 has path => (
     is => "rw",
@@ -42,11 +42,11 @@ Crypt::Random::Source::Base::File - File (or device) random data sources
 
 =head1 VERSION
 
-version 0.08
+version 0.12
 
 =head1 SYNOPSIS
 
-    use Moose;
+    use Moo;
     extends qw(Crypt::Random::Source::Base::File);
 
     has '+path' => (
@@ -69,11 +69,16 @@ A required attribute, the path to the file to open.
 
 Uses L<IO::File> to open C<path> for reading.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
