@@ -1,7 +1,7 @@
 package Crypt::Random::Source::Base::Handle;
 # ABSTRACT: L<IO::Handle> based random data sources
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moo;
 use Types::Standard qw(Bool);
@@ -110,11 +110,11 @@ Crypt::Random::Source::Base::Handle - L<IO::Handle> based random data sources
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-    use Moose;
+    use Moo;
     extends qw(Crypt::Random::Source::Base::Handle);
 
     sub open_handle {
