@@ -1,7 +1,7 @@
 package Crypt::Random::Source::Base::Proc;
 # ABSTRACT: Base class for helper processes (e.g. C<openssl>)
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moo;
 
@@ -66,12 +66,11 @@ Crypt::Random::Source::Base::Proc - Base class for helper processes (e.g. C<open
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-    use Moose;
-
+    use Moo;
     extends qw(Crypt::Random::Source::Base::Proc);
 
     has '+command' => ( default => ... );
