@@ -1,7 +1,7 @@
 package Crypt::Random::Source::Weak;
 # ABSTRACT: Abstract base class for weak random data sources
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Moo;
 use namespace::clean;
@@ -20,12 +20,11 @@ Crypt::Random::Source::Weak - Abstract base class for weak random data sources
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-    use Moose;
-
+    use Moo;
     extends qw(Crypt::Random::Source::Weak);
 
 =head1 DESCRIPTION
